summaryrefslogtreecommitdiffstats
path: root/libkscan/scanparams.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:21:13 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:21:13 -0600
commitebbee358abafa1b5166404c6fe5cc44ae2837a57 (patch)
tree268d36bbf4de9fb4007a1419b132b8b95251b99d /libkscan/scanparams.cpp
parent74c05bbf9d92e43a6cf3799355b5f3598884409e (diff)
downloadtdegraphics-ebbee358abafa1b5166404c6fe5cc44ae2837a57.tar.gz
tdegraphics-ebbee358abafa1b5166404c6fe5cc44ae2837a57.zip
Rename obsolete tq methods to standard names
Diffstat (limited to 'libkscan/scanparams.cpp')
-rw-r--r--libkscan/scanparams.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/libkscan/scanparams.cpp b/libkscan/scanparams.cpp
index 422eed4a..636b96df 100644
--- a/libkscan/scanparams.cpp
+++ b/libkscan/scanparams.cpp
@@ -111,7 +111,7 @@ bool ScanParams::connectDevice( KScanDevice *newScanDevice )
/* initialise own widgets */
cb_gray_preview = 0;
/* A top tqlayout box */
// TQVBoxLayout *top = new TQVBoxLayout(this, 6);
TQHBox *hb = new TQHBox( this );
hb->setSpacing( KDialog::spacingHint() );
@@ -160,7 +160,7 @@ bool ScanParams::connectDevice( KScanDevice *newScanDevice )
connect( pb, TQT_SIGNAL(clicked()), this, TQT_SLOT(slStartScan()) );
pb = kbb->addButton( i18n( "&Preview Scan" ));
connect( pb, TQT_SIGNAL(clicked()), this, TQT_SLOT(slAcquirePreview()) );
- kbb->tqlayout();
+ kbb->layout();
/* Initialise the progress dialog */
progressDialog = new TQProgressDialog( i18n("Scanning in progress"),
@@ -111,7 +111,7 @@ bool ScanParams::connectDevice( KScanDevice *newScanDevice )
/* initialise own widgets */
cb_gray_preview = 0;
- /* A top tqlayout box */
+ /* A top layout box */
// TQVBoxLayout *top = new TQVBoxLayout(this, 6);
TQHBox *hb = new TQHBox( this );